The files in this directory were used in the first implementation of vcd-cli (vca-cli) for:

- guest OS customization
- configuring NAT rules in edge gateway
- configuring VPN tunnels in edge gateway

We are keeping these files in the new version implementation of vcd-cli as a reminder that we need to bring back these features.
